package io.data2viz.charts.event

import io.data2viz.charts.chart.internal.NO_MARK_SELECTION_KEY
import io.data2viz.charts.core.Datum

/**
 * A "highlight event" is generally triggered when a user interacts with a [Mark] by rolling over it.
 *
 * @param indexedData the map of [Datum] to highlight for each markIndex
 * @param data the list of [Datum] to highlight.
 */
public class HighlightEvent<DOMAIN>internal constructor(
    public val indexedData: Map<Int, Collection<Datum<DOMAIN>>>,
) : ChartEvent {

    override var preventDefault: Boolean = false

    public val data: List<Datum<DOMAIN>> by lazy { indexedData.flatMap { it.value }.toSet().toList() }
}

public fun <DOMAIN> HighlightEvent(data: Collection<Datum<DOMAIN>>):HighlightEvent<DOMAIN>  = HighlightEvent(
    mapOf(NO_MARK_SELECTION_KEY to data))
