package io.data2viz.charts.event

import io.data2viz.charts.chart.internal.NO_MARK_SELECTION_KEY
import io.data2viz.charts.core.Datum
import io.data2viz.charts.core.MarkIndexedDatum

/**
 * A "selection event" is generally triggered when a user interacts with a [Mark] by clicking on it.
 *
 * @param indexedData the map of [Datum] to select for each markIndex
 * @param data the list of [Datum] to select.
 */
public class SelectEvent<DOMAIN> internal constructor(
    public val indexedData: Map<Int, Collection<Datum<DOMAIN>>>,
) : ChartEvent {

    override var preventDefault: Boolean = false

    public val data: List<Datum<DOMAIN>> by lazy { indexedData.flatMap { it.value }.toSet().toList() }
}

public fun <DOMAIN> SelectEvent(data: Collection<Datum<DOMAIN>>):SelectEvent<DOMAIN>  = SelectEvent(
    mapOf(NO_MARK_SELECTION_KEY to data))
